@@ -28,7 +28,7 @@ class FeatureStore:
         return jwt
 
     @staticmethod
-    def get(view: str, id: str) -> dict:
+    def get(view: str, id: str) -> requests.Response:
         # Provide the token in the request to the receiving service
         receiving_service_headers = {
             'Authorization': f'bearer {FeatureStore._get_bearer()}',
@@ -36,15 +36,11 @@ class FeatureStore:
         }
 
         # sending the request. Please make sure the payload is a valid json string
-        response = requests.get(url=f"{FeatureStore.HOST}/kinds/{view}/{id}",
+        return requests.get(url=f"{FeatureStore.HOST}/kinds/{view}/{id}",
                                 headers=receiving_service_headers)
 
-        if response.status_code != 200:
-            raise Exception(f'Error while requesting the FeatureStore:{response} status_code:{response.status_code}')
-        return json.loads(response.content)
-
     @staticmethod
-    def get_bulk(view: str, ids: list) -> dict:
+    def get_bulk(view: str, ids: list) -> requests.Response:
         # Provide the token in the request to the receiving service
         receiving_service_headers = {
             'Authorization': f'bearer {FeatureStore._get_bearer()}',
@@ -53,10 +49,6 @@ class FeatureStore:
 
         # sending the request. Please make sure the payload is a valid json string
 
-        response = requests.post(url=f"{FeatureStore.HOST}/kinds/{view}",
+        return requests.post(url=f"{FeatureStore.HOST}/kinds/{view}",
                                 data=json.dumps({"ids": ids}),
-                                headers=receiving_service_headers)
-
-        if response.status_code != 200:
-            raise Exception(f'Error while requesting the FeatureStore:{response} status_code:{response.status_code}')
-        return json.loads(response.content)
\ No newline at end of file
+                                headers=receiving_service_headers)
\ No newline at end of file
